Struct date_component::date_component::DateComponent[][src]

pub struct DateComponent {
    pub year: isize,
    pub month: isize,
    pub day: isize,
    pub interval_day: isize,
    pub invert: bool,
}

Fields

year: isize

Number of years.

month: isize

Number of months.

day: isize

Number of days.

interval_day: isize

total number of days between the start and end dates

invert: bool

Is true if the interval represents a negative time period and false otherwise